classdef headGrid % a grid used in Measure Projection
    properties
        spacing  = 10; % space between grid points (in mm).
        minGridLocation = [-88 -121  -77];
        maxGridLocation = [89   90   99];
        xCube, yCube, zCube % 3d array containing x, y or z values of grid points, meshgrid() output style.
        insideBrainCube % for each point in the 3D grid, it specifies whetehr it is inside brain volume or not.        
        cubeSize
    end % properties
    methods
        function obj = headGrid(spacing, minGridLocation, maxGridLocation) % constructor
            
            if nargin > 0
                obj.spacing = spacing;
            end;
            
            if nargin > 1
                obj.minGridLocation = minGridLocation;
            end;
            
            if nargin > 2
                obj.maxGridLocation = maxGridLocation;
            end;
            
            [obj.xCube obj.yCube obj.zCube] = meshgrid(obj.minGridLocation(1):obj.spacing:obj.maxGridLocation(1), obj.minGridLocation(2):obj.spacing:obj.maxGridLocation(2), obj.minGridLocation(3):obj.spacing:obj.maxGridLocation(3));
            
            obj.cubeSize = size(obj.xCube);
            
            % find grid locations that are inside brain
            gridPosition = [obj.xCube(:) obj.yCube(:) obj.zCube(:)];
            
            dipfitdefs; % get the location of standard BEM volume file
            tmp = load('-mat',DIPOLEDENSITY_STDBEM); % load MNI mesh
                      
            %addpath /home/nima/tools/clustering/projection/fieldtrip_private
            obj.insideBrainCube = reshape(inside_vol(gridPosition, tmp.vol), size(obj.xCube));
            %rmpath /home/nima/tools/clustering/projection/fieldtrip_private
        end;
        function plotScatter(obj) % plot a general scatter overview of the grid and brain 
            figure; 
            scatter3(obj.xCube(:), obj.yCube(:), obj.zCube(:), 1+obj.insideBrainCube(:) * 50, 'filled');
            axis equal;
        end;
        function plot(obj) % plot a general volumetric overview of the grid and brain
            figure;
            plot_dipplot_with_cortex;
            plot_head_region(obj, obj.insideBrainCube, 'g');
        end;
        function position = getPosition(obj, id) % return an N x 3 array containing grid positions.
            
            if nargin < 2
                id = obj.insideBrainCube;
            end;
            
            if ischar(id) && strcmpi(id, 'all')
                id = (1:numel(obj.xCube))';
            end;
            
            position = [obj.xCube(id) obj.yCube(id) obj.zCube(id)];
        end;
    end;
end